//spi.c
#include "spi.h"

unsigned long SPISetBaudRate(unsigned long baudrate, unsigned long systemfreq)
{
    ///Compute the new value for SPICK
    //baudrate = systemfreq / (2 * (SPICK + 1))
    unsigned long spick = ((systemfreq / baudrate) >> 1);

    //Only divide ratios between 1 & 256 are supported
    spick &= 0x0FF;

    //Set the SPICK register
    S0SPCCR = (spick & 0x0FF);

    //Return the actual value achieved
    return (systemfreq / ((spick + 1) << 1));
}


void InitSPI(unsigned char mode)
{
  PINSEL0_bit.P0_4 = 0x1;   // Use alternate functionality for the SPI0 pins
  PINSEL0_bit.P0_5 = 0x1;   // P0.7 (SSEL0) is mapped to CCS and is software
  PINSEL0_bit.P0_6 = 0x1;   // controlled - e.g. used as GPIO
  PINSEL0_bit.P0_7 = 0x0;


  //Master mode (1) or Slave mode (0)
  S0SPCR_bit.MSTR   = mode;

  //ClockPhase (active)
  S0SPCR_bit.CPHA   = 0;

  //Set Baund Rate
  //1st operand - data rate - must be max 1/8 from System frequency
  //2nd operand - system freguency
  SPISetBaudRate(1000000, 12000000);   // At 600000 we get choppy sound with
                                      // 320kbps mp3 files. At 1200000 we get
                                      // transfer errors.1000000 seems to be OK
}

unsigned char TransmitChar(unsigned char ch)
{
    //NOTE!!! This function send character to SPI bus when mode is MASTER
    //NOTE!!! This function receive character from SPI when mode is SLAVE
  S0SPDR_bit.DATA = ch;
  while(!S0SPSR_bit.SPIF);
  return((unsigned char)S0SPDR_bit.DATA);
}
